@@ -210,10 +210,10 @@ class RKXMLRequest(XMLRequest):
                     order_id=(order.get('OrderID')), count_guest=(visit.get('GuestsCount')),
                     order_name=(order.get('OrderName')), url=(order.get('Url')),
                     version=(order.get('Version')), crc32=(order.get('Crc32')),
-                    guid=(order.get('Guid')), table_id=(order.get('TableId')),
+                    guid=(order.get('Guid')), table_id=(order.get('TableID')),
                     table_code=(order.get('TableCode')), order_categ_id=(order.get('OrderCategId')),
                     order_categ_code=(order.get('OrderCategCode')), bill=(order.get('Bill')),
-                    waiter_id=(order.get('WaiterId')), order_type_code=(order.get('OrderTypeCode')),
+                    waiter_id=(order.get('WaiterID')), order_type_code=(order.get('OrderTypeCode')),
                     order_type_id=(order.get('OrderTypeId')), to_pay_sum=(order.get('ToPaySum')),
                     waiter_code=(order.get('WaiterCode')), order_sum=(order.get('OrderSum')),
                     total_pieces=(order.get('TotalPieces')), finished=(order.get('Finished')),
